#include "editarreceta.h"
#include "ui_editarreceta.h"

#include <QFile>
#include <QTextStream>
#include <QMessageBox>

/**
 * @brief EditarReceta::EditarReceta
 * Constructor de la clase encargada del manejo de editores de texto para su correcta ejecucion en la interfaz grafica.
 * @param parent Variable tipo Qwidget.
 */
EditarReceta::EditarReceta(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::EditarReceta)
{
    ui->setupUi(this);
    this->setWindowFlags(this->windowFlags() & ~Qt::WindowContextHelpButtonHint);

    ui->EditProcedimiento->hide(); /** <Esconde editor de procedimiento. */
    ui->EditIngrediente->hide(); /** <Esconde editor de ingredientes. */
    ui->NomReceta->hide(); /** <Esconde editor de nombre de la receta. */
    ui->FinEdit->hide(); /** <Esconde finalizacion de la edicion. */

    QFile list_nom_rec("Listado.txt");

    if(!list_nom_rec.open(QIODevice::ReadOnly))
        /**
         * @brief QMessageBox::information
         * Informa si hay un error de lectura o si el recetario esta vacio.
         */
        QMessageBox::information(0,"Error de lectura","Su recetario se encuentra vacío.");

    while(!list_nom_rec.atEnd()){
        ui->comboBox->addItem(list_nom_rec.readLine());
    }

    list_nom_rec.close();
}

/**
 * @brief EditarReceta::~EditarReceta
 * Destructor de la clase.
 */
EditarReceta::~EditarReceta()
{
    delete ui;
}

/**
 * @brief EditarReceta::on_RecetaEdit_released
 * Funcion para editar una receta.
 * Abre los archivos correspondientes para la edicion de cada receta.
 */
void EditarReceta::on_RecetaEdit_released()
{
    QString nombre=(ui->comboBox->currentText().trimmed());
    QFile archivo("Ingredientes/"+nombre+"_ing.txt");
    QFile file("Procedimiento/"+nombre+".txt");

    if(!file.open(QIODevice::ReadOnly) || !archivo.open(QIODevice::ReadOnly) )
        /**
         * @brief QMessageBox::information
         * Entrega informacion de error de lectura o de archivo no encontrado.
         */
        QMessageBox::information(0,"Error de lectura","Archivo no encontrado.\nVerifique escritura.");

    ui->NomReceta->setText(nombre);


    QTextStream in(&file);
    ui->EditProcedimiento->setText(in.readAll());
    ui->EditProcedimiento->setReadOnly(false);

    QTextStream ining(&archivo);
    ui->EditIngrediente->setText(ining.readAll());
    ui->EditIngrediente->setReadOnly(false);

    ui->EditProcedimiento->show();
    ui->EditIngrediente->show();
    ui->label_2->show();
    ui->FinEdit->show();
    ui->NomReceta->show();
}

/**
 * @brief EditarReceta::on_FinEdit_clicked
 * Finaliza la edicion de la receta.
 * Envia los datos, guardandolos correctamente para finalizar la edicion de una receta.
 */
void EditarReceta::on_FinEdit_clicked()
{
    QString nombre=ui->comboBox->currentText().trimmed();
    QFile archivo("Ingredientes/"+nombre+"_ing.txt"); /** <Abre el archivo de los ingredientes de la receta. */
    QFile file("Procedimiento/"+nombre+".txt"); /** <Abre el archivo de los procedimiento de la receta. */
    if(!file.open(QFile::WriteOnly | QFile::Text) || !archivo.open(QFile::WriteOnly | QFile::Text))
        /**
         * @brief QMessageBox::information
         * Entrega informacion de error de lectura o de archivo no encontrado.
         */
        QMessageBox::information(0,"Error de lectura","Archivo no encontrado.\nVerifique escritura.");

    QTextStream out(&file);
    QTextStream out2(&archivo);
    out << ui->EditProcedimiento->toPlainText(); /** < Guarda lo ingresado en out. */
    out2 << ui->EditIngrediente->toPlainText(); /** < Guarda lo ingresado en out2. */

    file.flush(); /** < Guarda lo que contiene out en un archivo de texto. */
    archivo.flush(); /** < Guarda lo que contiene out2 en un archivo de texto */
    archivo.close();
    file.close();

    /**
     * @brief guardarreceta
     * Entrega informacion de archivo guardado correctamente y pregunta si se desea terminar con la edicion.
     */
    QMessageBox guardarreceta(QMessageBox::NoIcon,
        tr("Guardar"),
        tr("Su receta se ha guardado exitosamente.\n¿Desea terminar la edición?"),
        QMessageBox::Yes | QMessageBox::No,
        this);
    guardarreceta.setButtonText(QMessageBox::Yes, tr("Sí"));
    guardarreceta.setButtonText(QMessageBox::No, tr("No"));
    if(guardarreceta.exec() == QMessageBox::Yes)
        this->close();
    else
        guardarreceta.close();
}

/**
 * @brief EditarReceta::on_VolverEdit_released
 * Vuelve a la pagina pricipal de opciones.
 * Cierra la ventana de edicion.
 */
void EditarReceta::on_VolverEdit_released()
{
    this->close();
}

